==> codemirror-editor-vue3-knowit-vite-0.0.25.tgz: package/README.md <==
# Codemirror + Validation ( JSON / XML )

This project is created to help us validate XML or JSON scheme inside of Codemirror plugin.
** Work in progress **
## Feat:

- Validate XML
- Validate JSON
- Export errors as a filet

## Installation

```bash
npm i codemirror-editor-vue3-knowit-vite
```

```main.js
import CodeEditor from "codemirror-editor-vue3-knowit-vite"
import "codemirror-editor-vue3-knowit-vite/dist/style.css"

const app = createApp(App);
app.use(CodeEditor)
app.mount('#app')
```

```Usage example invalid XML on scheme
<template>
  <code-editor :type="type" :content="content"></code-editor>
</template>

<script>

export default {
  data() {
    return {
      type: 'xml',
      content: `<?xml version="1.0" encoding="UTF-8" ?>
      <Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners>`,
      schemaUrl: ''
    };
  },
};
</script>
```

## TODO:

- Translation XML  (СРБ - ENG)
- Translation JSON (СРБ - ENG)

### Vue 3 + Vite

This template should help get you started developing with Vue 3 in Vite. The template uses Vue 3 `<script setup>` SFCs, check out the [script setup docs](https://v3.vuejs.org/api/sfc-script-setup.html#sfc-script-setup) to learn more.

### Recommended IDE Setup

- [VS Code](https://code.visualstudio.com/) + [Volar](https://marketplace.visualstudio.com/items?itemName=Vue.volar) (and disable Vetur) + [TypeScript Vue Plugin (Volar)](https://marketplace.visualstudio.com/items?itemName=Vue.vscode-typescript-vue-plugin).

==> codemirror-editor-vue3-knowit-vite-0.0.26.tgz: package/README.md <==
# Codemirror + Validation ( JSON / XML )
**Work in progress**
This project is created to help us validate XML or JSON scheme inside of Codemirror plugin.

## Feat:

- Validate XML
- Validate JSON
- Export errors as a file

## Installation

```bash
npm i codemirror-editor-vue3-knowit-vite
```

```main.js
import CodeEditor from "codemirror-editor-vue3-knowit-vite"
import "codemirror-editor-vue3-knowit-vite/dist/style.css"

const app = createApp(App);
app.use(CodeEditor)
app.mount('#app')
```

```Usage example invalid XML on scheme
<template>
  <code-editor :type="type" :content="content"></code-editor>
</template>

<script>

export default {
  data() {
    return {
      type: 'xml',
      content: `<?xml version="1.0" encoding="UTF-8" ?>
      <Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners><Partners>
        <Partner>
          <Nam>ldMsyR</Name>
          <Address>Test Adresa</Address>
          <BankAccount>000000000000963289</BankAccount>
          <Comment>Test Komentar</Comment>
        </Partner>
      </Partners>`,
      schemaUrl: ''
    };
  },
};
</script>
```

## TODO:

- Translation XML  (СРБ - ENG)
- Translation JSON (СРБ - ENG)

### Vue 3 + Vite

This template should help get you started developing with Vue 3 in Vite. The template uses Vue 3 `<script setup>` SFCs, check out the [script setup docs](https://v3.vuejs.org/api/sfc-script-setup.html#sfc-script-setup) to learn more.

### Recommended IDE Setup

- [VS Code](https://code.visualstudio.com/) + [Volar](https://marketplace.visualstudio.com/items?itemName=Vue.volar) (and disable Vetur) + [TypeScript Vue Plugin (Volar)](https://marketplace.visualstudio.com/items?itemName=Vue.vscode-typescript-vue-plugin).
